#
# spec file for package python-hstspreload
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-hstspreload
Version:        2024.11.1
Release:        1.3
Summary:        Python Chromium HSTS Preload list
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://github.com/sethmlarson/hstspreload
Source:         https://files.pythonhosted.org/packages/source/h/hstspreload/hstspreload-%{version}.tar.gz
Source1:        https://raw.githubusercontent.com/python-http/hstspreload/master/test_hstspreload.py
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Chromium HSTS Preload list as a Python package.

%prep
%setup -q -n hstspreload-%{version}
cp %{SOURCE1} .

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

#%%check depends on httpx, which depends on hstspreload
# Also, depends on the huge static data, and tests seem to fail ATM.
#%%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/*

%changelog
* Wed Nov 13 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.11.1:
  * Automated updates to the HSTS preload list on 2024-11-1
* Tue Oct 29 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.10.1:
  * Automated updates to the HSTS preload list on 2024-10-1
* Wed Aug 21 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.8.1:
  * Automated updates to the HSTS preload list on 2024-8-1
* Tue Jun  4 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.6.1:
  * Automated updates to the HSTS preload list on 2024-6-1
* Tue May  7 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.5.1:
  * Automated updates to the HSTS preload list on 2024-5-1
* Wed Apr  3 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.4.1:
  * Automated updates to the HSTS preload list on 2024-4-1
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.3.1:
  * Automated updates to the HSTS preload list on 2024-3-1
* Wed Feb  7 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.2.1:
  * Automated updates to the HSTS preload list on 2024-2-1
* Sat Jan 13 2024 Dirk Müller <dmueller@suse.com>
- update to 2024.1.5:
  * Automated updates to the HSTS preload list on 2024-1-5
* Wed Jan  4 2023 Dirk Müller <dmueller@suse.com>
- update to 2023.1.1:
  * Automated updates to the HSTS preload list on 2023-1-1
* Wed Dec  7 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2022.12.1
  * Automated updates to the HSTS preload list on 2022-12-1
* Tue Nov  8 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2022.11.1
  Automated updates to the HSTS preload list on 2022-11-1
* Fri Oct 28 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2022.10.1
  * Automated updates to the HSTS preload list on 2022-10-1
* Thu Sep 29 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to 2022.9.1
  - Automated updates to the HSTS preload list on 2022-9-1
  * Automated updates to the HSTS preload list on 2022-8-1
  * Fix build module name
  * Automated updates to the HSTS preload list on 2022-7-10
  * forgot flake8
  * Also update the test URL
  * Move requirements to their own directory
  * Allow manually running cron.sh
  * Update branch from 'master' to 'main' of Chromium repository
  * Add explicit support for Python 3.9 and 3.10
  * Automated updates to the HSTS preload list on 2021-12-1
  * Automated updates to the HSTS preload list on 2021-11-1
  * Automated updates to the HSTS preload list on 2021-10-1
  * Automated updates to the HSTS preload list on 2021-9-1
  * Automated updates to the HSTS preload list on 2021-8-1
  * Run monthly instead of weekly
  * Use env field in GHA
  * Fix cron? add manual deploy
  * Automated updates to the HSTS preload list on 2021-7-5
  * Automated updates to the HSTS preload list on 2021-6-28
  * Automated updates to the HSTS preload list on 2021-6-21
  * Automated updates to the HSTS preload list on 2021-6-14
  * Automated updates to the HSTS preload list on 2021-5-31
  * Automated updates to the HSTS preload list on 2021-5-24
  * Automated updates to the HSTS preload list on 2021-5-17
  * Use main instead of master
  * Update cron.sh
  * Automated updates to the HSTS preload list on 2021-5-3
  * Automated updates to the HSTS preload list on 2021-4-26
  * Automated updates to the HSTS preload list on 2021-4-19
  * Automated updates to the HSTS preload list on 2021-4-12
  * Automated updates to the HSTS preload list on 2021-3-29
  * Automated updates to the HSTS preload list on 2021-3-22
  * Automated updates to the HSTS preload list on 2021-3-8
  * Automated updates to the HSTS preload list on 2021-3-1
  * Automated updates to the HSTS preload list on 2021-2-15
  * Automated updates to the HSTS preload list on 2021-2-1
  * Automated updates to the HSTS preload list on 2021-1-25
  * Add shields to README
  * Automated updates to the HSTS preload list on 2021-1-11
  * Automated updates to the HSTS preload list on 2020-12-22
  * Use lint nox session
* Sat Nov 21 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v2020.11.21
* Tue Oct 13 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v2020.10.6
* Thu Aug 27 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v2020.8.25
* Tue Feb 18 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v2020.2.15
* Tue Oct  8 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v2019.9.30
